// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef TEXTTRANSLATE_VERSION_H
#define TEXTTRANSLATE_VERSION_H

#define TEXTTRANSLATE_VERSION_STRING "2.1.2"
#define TEXTTRANSLATE_VERSION_MAJOR 2
#define TEXTTRANSLATE_VERSION_MINOR 1
#define TEXTTRANSLATE_VERSION_PATCH 2
#define TEXTTRANSLATE_VERSION ((2<<16)|(1<<8)|(2))

#endif
