// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef TEXTUTILS_VERSION_H
#define TEXTUTILS_VERSION_H

#define TEXTUTILS_VERSION_STRING "2.1.2"
#define TEXTUTILS_VERSION_MAJOR 2
#define TEXTUTILS_VERSION_MINOR 1
#define TEXTUTILS_VERSION_PATCH 2
#define TEXTUTILS_VERSION ((2<<16)|(1<<8)|(2))

#endif
